@@ -46,8 +46,8 @@ class DatabaseHandler:
     def read_events(self):
         try:
             self.db_trk = pd.read_csv(self._db_path)
-            self.db_trk["start_time"] = pd.to_datetime(self.db_trk["start_time"], format =  "%Y-%m-%d %H:%M:%S" )
-            self.db_trk["end_time"] = pd.to_datetime(self.db_trk["end_time"], format =  "%Y-%m-%d %H:%M:%S" )
+            self.db_trk["start_time"] = pd.to_datetime(self.db_trk["start_time"], errors='ignore', format =  "%Y-%m-%d %H:%M:%S" )
+            self.db_trk["end_time"] = pd.to_datetime(self.db_trk["end_time"],errors='ignore', format =  "%Y-%m-%d %H:%M:%S" )
             return(self.db_trk)
 
         except OSError:
