@@ -80,7 +80,19 @@ def init(
     else:
         typer.secho(f"The time tracker database is {db_path}", fg=typer.colors.GREEN)
     
+@app.command()
+def switch(db_path: str = typer.Option(
+        str(database.DEFAULT_DB_FILE_PATH),
+        "--db-path",
+        "-db",
+        prompt="time tracker database location?"
+    )):
 
+    config._create_database(db_path)
+
+    typer.echo(f"Default database was switched to: {db_path}")
+
+    pass
 
 @app.command()
 def start(event: str = typer.Argument(...), 
@@ -212,14 +224,17 @@ def list(column_name: str):
     typer.echo(tabulate(values, showindex= False, headers = "keys"))
 
 @app.command()
-def summary(column_names: List[str]):
+def summary(column_names: List[str], today: bool =  typer.Option(False, "--today", "-t", help = "filter for today's date")
+
+
+):
     """Return a summary table"""
     tracker = get_tracker()
     ls_column_names = []
     for i in column_names:
         ls_column_names.append(i)
     #typer.echo(type(ls_column_names))
-    summary = tracker.summary(ls_column_names)
+    summary = tracker.summary(ls_column_names, today)
     typer.echo("\n")
     typer.echo(tabulate(summary, showindex= False, headers = "keys" ))
     typer.echo("\n")
